@@ -19,6 +19,7 @@ class LicenseHistoryMessUsedModel(BaseCollectionMongoDB):
     gift = "gift"
     mess_surplus = "mess_surplus"
     create_on = "create_on"
+    child_merchant_id = "child_merchant_id"
 
     def __init__(self):
         super().__init__()
@@ -30,6 +31,11 @@ class LicenseHistoryMessUsedModel(BaseCollectionMongoDB):
 
     def insert_license_history_mess_used(self, data_insert):
         try:
+            print(
+                "license_sdk::insert_license_history_mess_used data_insert: {}".format(
+                    data_insert
+                )
+            )
             result = self.coll_primary.insert_one(data_insert)
             if result.inserted_id is not None:
                 return 1
