@@ -1,5 +1,6 @@
 from .mongo_connection import BaseCollectionMongoDB
 from pymongo import ReadPreference
+from .date_utils import get_utc_now, convert_date_to_format
 
 
 class LicenseMessUsedModel(BaseCollectionMongoDB):
@@ -18,6 +19,8 @@ class LicenseMessUsedModel(BaseCollectionMongoDB):
     gift = "gift"
     mess_surplus = "mess_surplus"
     check_sum = "check_sum"
+    create_on = "create_on"
+    update_on = "update_on"
 
     def __init__(self):
         super().__init__()
@@ -33,6 +36,7 @@ class LicenseMessUsedModel(BaseCollectionMongoDB):
                 {self.merchant_id: merchant_id, self.month: day_of_month},
                 {self._ID: 0},
             )
+            print("license_sdk::find_one_license_mess_used result: {}".format(result))
             return result
         except Exception as er:
             err_msg = "license_sdk find_one_license_mess_used ERR: {}".format(er)
@@ -41,10 +45,12 @@ class LicenseMessUsedModel(BaseCollectionMongoDB):
 
     def upsert_data_mess_used(self, merchant_id, day_of_month, data):
         try:
+            dnow_utc = convert_date_to_format(get_utc_now())
             result = self.coll_primary.update_one(
                 {self.merchant_id: merchant_id, self.month: day_of_month},
                 {
                     "$set": data,
+                    "$setOnInsert": {self.create_on: dnow_utc},
                 },
                 upsert=True,
             )
@@ -65,4 +71,6 @@ class LicenseMessUsedModel(BaseCollectionMongoDB):
         data_str += "_" + str(data_mess.get(self.gift, 0))
         data_str += "_" + str(data_mess.get(self.gift_used, 0))
         data_str += "_" + str(data_mess.get(self.mess_surplus, 0))
+        # data_str += "_" + str(data_mess.get(self.create_on, ""))
+        # data_str += "_" + str(data_mess.get(self.update_on, ""))
         return data_str
