@@ -1,66 +1,9 @@
 from .crypt_utils import CryptUtil
-import datetime
 from .license_mess_used import LicenseMessUsedModel
 from .license_detail_mess_used import LicenseDetailMessUsedModel
-import uuid
 from copy import deepcopy
 from .license_history_mess_used import LicenseHistoryMessUsedModel
-
-
-def ConvertDateUTCtoStringITC(date_input_time, tz_minute, dinhdang="%H:%M %d/%m/%Y"):
-    try:
-        thoi_gian_itc = date_input_time + datetime.timedelta(minutes=tz_minute)
-        return thoi_gian_itc.strftime(dinhdang)
-    except:
-        return ""
-
-
-def convert_date_to_format(vNgayThang, format="%Y%m%d%H%M%S"):
-    try:
-        if vNgayThang is not None:
-            return vNgayThang.strftime(format)
-        else:
-            return ""
-    except:
-        return ""
-
-
-def convert_str_to_date(date_str, format="%Y%m%d%H%M%S"):
-    try:
-        return datetime.datetime.strptime(date_str, format).replace(
-            tzinfo=datetime.timezone.utc
-        )
-    except:
-        return None
-
-
-def get_utc_now():
-    now = datetime.datetime.utcnow().replace(tzinfo=datetime.timezone.utc)
-    return now
-
-
-def convert_timestamp_to_date_utc(timestamp):
-    try:
-        if timestamp is not None:
-            return datetime.datetime.utcfromtimestamp(timestamp).replace(
-                tzinfo=datetime.timezone.utc
-            )
-        else:
-            return None
-    except:
-        return None
-
-
-def convert_date_utc_to_date_itc(date_input_time, tz_minute):
-    try:
-        thoi_gian_itc = date_input_time + datetime.timedelta(minutes=tz_minute)
-        return thoi_gian_itc
-    except:
-        return None
-
-
-def generate_uuid():
-    return str(uuid.uuid1())
+from .date_utils import *
 
 
 class Utils:
@@ -121,6 +64,11 @@ class Utils:
                 if item.get("type_use") == "one_times":
                     data_number_mess[item.get("gift_code")] = item.get("number", 0)
                     list_gift_code.append(item.get("gift_code"))
+        print(
+            "license_sdk::get_mess_allow_in_license list_block_mess_id: {}, list_gift_code: {}, data_number_mess: {}".format(
+                list_block_mess_id, list_gift_code, data_number_mess
+            )
+        )
         return list_block_mess_id, list_gift_code, data_number_mess
 
     @staticmethod
@@ -139,6 +87,11 @@ class Utils:
                 Utils.DATE_YYYYmm,
             )
             month_get_mess = convert_date_to_format(dnow_itc, Utils.DATE_YYYYmm)
+        print(
+            "license_sdk::get_time_using_mess month_get_mess: {}, last_month: {}".format(
+                month_get_mess, last_month
+            )
+        )
         return month_get_mess, last_month
 
     @staticmethod
@@ -200,6 +153,16 @@ class Utils:
                         list_id_remaining_gift[key] = value
         data_remaining_messages["total_mess_buy"] = total_mess_buy
         data_remaining_messages["total_mess_gift"] = total_mess_gift
+        print(
+            "license_sdk::get_number_remaining_messages data_remaining_messages: {}, total_mess: {}".format(
+                data_remaining_messages, total_mess
+            )
+        )
+        print(
+            "license_sdk::get_number_remaining_messages list_id_remaining_block: {}, list_id_remaining_gift: {}".format(
+                list_id_remaining_block, list_id_remaining_gift
+            )
+        )
         return (
             data_remaining_messages,
             total_mess,
@@ -210,10 +173,14 @@ class Utils:
     # tinh toan su dung mess can gui
     @staticmethod
     def create_number_mess_need_used(
-        license_key, merchant_id, number_mess_need_used=None, day_of_month=None
+        license_key, child_merchant_id, number_mess_need_used=None, day_of_month=None
     ):
         number_mess, messages, allow_use_mess = 0, "", 0
         try:
+            from .call_api import get_parent_id_from_merchant
+            print("license_sdk:: create_number_mess_need_used merchant_id: {}".format(child_merchant_id))
+            merchant_id = get_parent_id_from_merchant(child_merchant_id)
+            print("license_sdk:: create_number_mess_need_used root_merchant_id: {}".format(merchant_id))
             # lấy thông tin mess trong file license
             data_mess_license = Utils.get_data_mess_license(license_key, merchant_id)
             if data_mess_license:
@@ -221,7 +188,7 @@ class Utils:
                 # nếu base_messages < 0 nghĩa là gói enterprise ko giới hạn
                 if base_messages_package < 0:
                     print(
-                        "license_sdk::check_number_mess_allow_used(): mess unlimit on package enterprise_package"
+                        "license_sdk::create_number_mess_need_used(): mess unlimit on package enterprise_package"
                     )
                     return -1, "enterprise_package_unlimited", 1
                 # số mess dc sử dụng tăng thêm số base_messages
@@ -234,11 +201,7 @@ class Utils:
                     list_gift_code,
                     data_number_mess_license,
                 ) = Utils.get_mess_allow_in_license(data_mess_license, month_get_mess)
-                print(
-                    "license_sdk::check_number_mess_allow_used(): list_block_mess_id: {}, list_gift_code: {}, data_number_mess_license: {}".format(
-                        list_block_mess_id, list_gift_code, data_number_mess_license
-                    )
-                )
+
                 # tính toán số mess đã sử dụng trc đó(quà tặng, mua thêm) để ra số lượng còn lại
                 (
                     data_remaining_messages,
@@ -251,11 +214,7 @@ class Utils:
                     list_gift_code,
                     data_number_mess_license,
                 )
-                print(
-                    "license_sdk::check_number_mess_allow_used(): data_remaining_messages: {}, number_remaining_mess: {}".format(
-                        data_remaining_messages, number_remaining_mess
-                    )
-                )
+
                 # số mess dc sử dụng tăng thêm số mess mua thêm, quà tặng
                 number_mess += number_remaining_mess
                 # lấy thông tin sử dụng mess tháng hiện tại
@@ -273,7 +232,7 @@ class Utils:
                     data_mess_month_now
                 ) or not Utils.check_data_mess_used(data_mess_last_month):
                     print(
-                        "license_sdk::check_number_mess_allow_used(): data invalid checksum"
+                        "license_sdk::create_number_mess_need_used(): data invalid checksum"
                     )
                     return 0, "data_invalid_checksum", 0
 
@@ -363,14 +322,16 @@ class Utils:
                         list_id_remaining_block,
                         list_id_remaining_gift,
                         merchant_id,
+                        child_merchant_id
                     )
             else:
                 messages = "license_none"
-                print("license_sdk::check_number_mess_allow_used(): license none")
+                print("license_sdk::create_number_mess_need_used(): license none")
 
         except Exception as ex:
             messages = "error: {}".format(ex)
-            print("license_sdk::check_number_mess_allow_used():message: {}".format(ex))
+            print("license_sdk::create_number_mess_need_used():message: {}".format(ex))
+        print("license_sdk::create_number_mess_need_used return: number_mess: {}, messages: {}, allow_use_mess: {}".format(number_mess, messages, allow_use_mess))
         return number_mess, messages, allow_use_mess
 
     @staticmethod
@@ -384,6 +345,7 @@ class Utils:
         list_id_remaining_block,
         list_id_remaining_gift,
         merchant_id,
+        child_merchant_id
     ):
         try:
             total_mess_buy = data_remaining_messages.get("total_mess_buy", 0)
@@ -406,7 +368,7 @@ class Utils:
                     data_mess_month_now[LicenseMessUsedModel.mess_base_used] = (
                         mess_base_used + number_mess_need_used
                     )
-                    Utils.save_history_license_used_mess(data_mess_month_now)
+                    Utils.save_history_license_used_mess(data_mess_month_now, child_merchant_id)
                 else:
                     data_mess_month_now[LicenseMessUsedModel.mess_base_used] = mess_base
                     number_mess_need_used = number_mess_need_used - (
@@ -501,7 +463,7 @@ class Utils:
                             + number_mess_need_used
                         )
                     history_id = Utils.save_history_license_used_mess(
-                        data_mess_month_now
+                        data_mess_month_now, child_merchant_id
                     )
                     create_on = convert_date_to_format(get_utc_now())
                     for detail_mess in data_detail_mess:
@@ -511,6 +473,7 @@ class Utils:
                         ] = merchant_id
                         detail_mess[LicenseDetailMessUsedModel.month] = month_get_mess
                         detail_mess[LicenseDetailMessUsedModel.create_on] = create_on
+                        detail_mess[LicenseDetailMessUsedModel.child_merchant_id] = child_merchant_id
                     LicenseDetailMessUsedModel().insert_many_license_detail_mess_used(
                         data_detail_mess
                     )
@@ -624,7 +587,7 @@ class Utils:
                         LicenseMessUsedModel.gift_used: gift_used,
                         LicenseMessUsedModel.mess_surplus: mess_surplus,
                     }
-                    history_id = Utils.save_history_license_used_mess(data_mess_save)
+                    history_id = Utils.save_history_license_used_mess(data_mess_save, child_merchant_id)
                     create_on = convert_date_to_format(get_utc_now())
                     for detail_mess in data_detail_mess:
                         detail_mess[LicenseDetailMessUsedModel.history_id] = history_id
@@ -633,6 +596,7 @@ class Utils:
                         ] = merchant_id
                         detail_mess[LicenseDetailMessUsedModel.month] = month_get_mess
                         detail_mess[LicenseDetailMessUsedModel.create_on] = create_on
+                        detail_mess[LicenseDetailMessUsedModel.child_merchant_id] = child_merchant_id
                     LicenseDetailMessUsedModel().insert_many_license_detail_mess_used(
                         data_detail_mess
                     )
@@ -644,13 +608,15 @@ class Utils:
             )
 
     @staticmethod
-    def save_history_license_used_mess(data_mess):
+    def save_history_license_used_mess(data_mess, child_merchant_id):
         try:
+            date_format = convert_date_to_format(get_utc_now())
             check_sum = CryptUtil.encrypt_mobio_crypt2(
                 LicenseMessUsedModel().data_mess_to_string(data_mess)
             )
             data_mess[LicenseMessUsedModel.check_sum] = check_sum
             data_history = deepcopy(data_mess)
+            data_mess[LicenseMessUsedModel.update_on] = date_format
             LicenseMessUsedModel().upsert_data_mess_used(
                 data_mess.get(LicenseMessUsedModel.merchant_id),
                 data_mess.get(LicenseMessUsedModel.month),
@@ -659,11 +625,42 @@ class Utils:
             data_history[LicenseHistoryMessUsedModel.history_id] = generate_uuid()
             data_history[
                 LicenseHistoryMessUsedModel.create_on
-            ] = convert_date_to_format(get_utc_now())
+            ] = date_format
+            data_history[LicenseHistoryMessUsedModel.child_merchant_id] = child_merchant_id
             LicenseHistoryMessUsedModel().insert_license_history_mess_used(data_history)
+            print(
+                "license_sdk::save_history_license_used_mess data_history: {}".format(
+                    data_history
+                )
+            )
             return data_history.get(LicenseHistoryMessUsedModel.history_id)
         except Exception as ex:
             print(
                 "license_sdk::save_history_license_used_mess():message: {}".format(ex)
             )
             return None
+
+    @staticmethod
+    def check_merchant_expire(license_key, merchant_id):
+        merchant_expire = True
+        try:
+            result = CryptUtil.get_license_info(license_key, merchant_id)
+            if (
+                result
+                and result.get("expire_time")
+                and convert_timestamp_to_date_utc(result.get("expire_time"))
+            ):
+                time_stamp_now = convert_date_to_timestamp(get_utc_now())
+                if result.get("expire_time") > time_stamp_now:
+                    merchant_expire = False
+                else:
+                    print(
+                        "license_sdk::check_time_merchant_expire license merchant expire_time"
+                    )
+            else:
+                print(
+                    "license_sdk::check_time_merchant_expire license expire_time not found"
+                )
+        except Exception as e:
+            print("license_sdk::check_time_merchant_expire: ERROR: %s" % e)
+        return merchant_expire
